# nr.powerline

Simple powerline implementation, only tested in Bash. It is recommended that
you use a font from [NerdFonts](https://nerdfonts.com/#downloads) in order to
have proper support for special characters (like the right triangle).

__Requirements__

- Bash
- Pipx
- Python 3.5+
- Linux/macOS
- jq

__Installation__

    $ pipx install nr.powerline
    $ source <(nr-powerline --src bash)

---

<p align="center">Copyright &copy; 2020 Niklas Rosenstein</p>
